@@ -4,16 +4,16 @@ from typing import List, Optional, Union
 import pydicom
 from pydicom import FileDataset
 
-from .dose_matrix import DoseMatrix
 from ..constants.SopClassUids import (
     RADIATION_DOSE_STRUCTURED_REPORT_SOP_CLASS_UIDS,
     SECONDARY_CAPTURE_SOP_CLASS_UIDS,
 )
+from ..helpers.check_path_is_valid import check_path_is_valid_path
 from .ct import CtSeries
 from .dicom_series import DicomSeries
+from .dose_matrix import DoseMatrix
 from .dose_report_class import DoseReport
 from .projection import ProjectionSeries
-from ..helpers.check_path_is_valid import check_path_is_valid_path
 
 
 class DicomStudy:
@@ -65,7 +65,7 @@ class DicomStudy:
             raise ValueError(f"The given DICOM file is not part of the study {self.StudyInstanceUid}")
 
         self.Manufacturer = dcm.Manufacturer
-        self.ManufacturerModelName = dcm.ManufacturerModelName
+        self.ManufacturerModelName = dcm.ManufacturerModelName if "ManufacturerModelName" in dcm else None
 
         if dcm.SOPClassUID in RADIATION_DOSE_STRUCTURED_REPORT_SOP_CLASS_UIDS + SECONDARY_CAPTURE_SOP_CLASS_UIDS:
             self.DoseReports.add_file(dataset=dcm)
